@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,8 +49,11 @@
 
 package com.openexchange.monitoring.osgi;
 
+import java.util.ArrayList;
+import java.util.List;
 import org.osgi.framework.BundleActivator;
 import org.osgi.framework.ServiceRegistration;
+import org.osgi.util.tracker.ServiceTracker;
 import com.openexchange.management.ManagementService;
 import com.openexchange.monitoring.MonitorService;
 import com.openexchange.monitoring.internal.MonitorImpl;
@@ -68,10 +71,12 @@ import com.openexchange.sessiond.SessiondService;
  */
 public final class MonitoringActivator extends DeferredActivator {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MonitoringActivator.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(MonitoringActivator.class));
 
     private ServiceRegistration serviceRegistration;
 
+    private List<ServiceTracker> trackers;
+
     /**
      * Initializes a new {@link MonitoringActivator}
      */
@@ -118,6 +123,13 @@ public final class MonitoringActivator extends DeferredActivator {
 
             MonitoringInit.getInstance().start();
 
+            trackers = new ArrayList<ServiceTracker>(2);
+            trackers.add(new MailCounterServiceTracker(context));
+            trackers.add(new MailIdleCounterServiceTracker(context));
+            for (final ServiceTracker tracker : trackers) {
+                tracker.open();
+            }
+
             /*
              * Register monitor service
              */
@@ -131,6 +143,12 @@ public final class MonitoringActivator extends DeferredActivator {
     @Override
     public void stopBundle() throws Exception {
         try {
+            if (null != trackers) {
+                while (!trackers.isEmpty()) {
+                    trackers.remove(0).close();
+                }
+                trackers = null;
+            }
             if (null != serviceRegistration) {
                 serviceRegistration.unregister();
                 serviceRegistration = null;
